summaryrefslogtreecommitdiff
path: root/bin
diff options
context:
space:
mode:
authorChristian Lohmaier <lohmaier+LibreOffice@googlemail.com>2022-12-15 14:00:28 +0100
committerChristian Lohmaier <lohmaier+LibreOffice@googlemail.com>2022-12-15 22:42:00 +0000
commitec4409a911fd4a67eb1bc74aae33081ae8510339 (patch)
tree1d6f7751dad1886d51638155a2cfb7204c4f4760 /bin
parentd117e3a45e662ac45b96c940459101376445a811 (diff)
don't export entries from download.lst - only used by make
no need to plant that into the environment of every recipe. some Jenkins Windows builders already run into "environment is too large for exec" issue just by attempting a "xargs --show-limits </dev/null" from a dummy rule within the make environment Change-Id: I321fa9075532eef62a7d4e33a08c272276de717e Reviewed-on: https://gerrit.libreoffice.org/c/core/+/144217 Tested-by: Jenkins Reviewed-by: Christian Lohmaier <lohmaier+LibreOffice@googlemail.com>
Diffstat (limited to 'bin')
-rwxr-xr-xbin/oss-fuzz-setup.sh4
1 files changed, 2 insertions, 2 deletions
diff --git a/bin/oss-fuzz-setup.sh b/bin/oss-fuzz-setup.sh
index 08cfa608464e..f5fc8fb7b305 100755
--- a/bin/oss-fuzz-setup.sh
+++ b/bin/oss-fuzz-setup.sh
@@ -4,8 +4,8 @@ set -e
echo start downloading dependencies at `date -u`
-# convert FOO := BAR$(MICRO) to FOO=BAR$MICRO
-source <(sed -e's# := #=#g' download.lst | sed -e 's#[)(]##g')
+# convert FOO := BAR$(MICRO) to export FOO=BAR$MICRO
+source <(sed -e's#\([^ ]\{1,\}\) := #export \1=#g' download.lst | sed -e 's#[)(]##g')
mkdir $SRC/external-tar
cd $SRC/external-tar